@@ -23,6 +23,7 @@ from pipenv.cli.options import (
     uninstall_options,
     verbose_option,
 )
+from pipenv.utils.environment import load_dot_env
 from pipenv.utils.processes import subprocess_run
 from pipenv.vendor.click import (
     Choice,
@@ -82,6 +83,8 @@ def cli(
     from pipenv.utils.shell import system_which
     from pipenv.utils.spinner import create_spinner
 
+    load_dot_env(state.project, quiet=state.quiet)
+
     from ..core import (
         cleanup_virtualenv,
         do_clear,
@@ -250,6 +253,7 @@ def install(state, **kwargs):
         packages=state.installstate.packages,
         editable_packages=state.installstate.editables,
         site_packages=state.site_packages,
+        extra_pip_args=state.installstate.extra_pip_args,
     )
 
 
@@ -370,7 +374,7 @@ def shell(
     anyway=False,
 ):
     """Spawns a shell within the virtualenv."""
-    from ..core import do_shell, load_dot_env
+    from ..core import do_shell
 
     # Prevent user from activating nested environments.
     if "PIPENV_ACTIVE" in os.environ:
@@ -420,7 +424,6 @@ def run(state, command, args):
         three=state.three,
         python=state.python,
         pypi_mirror=state.pypi_mirror,
-        quiet=state.quiet,
     )
 
 
@@ -561,6 +564,7 @@ def update(ctx, state, bare=False, dry_run=None, outdated=False, **kwargs):
         unused=False,
         sequential=state.installstate.sequential,
         pypi_mirror=state.pypi_mirror,
+        extra_pip_args=state.installstate.extra_pip_args,
     )
 
 
@@ -652,6 +656,7 @@ def sync(ctx, state, bare=False, user=False, unused=False, **kwargs):
         sequential=state.installstate.sequential,
         pypi_mirror=state.pypi_mirror,
         system=state.system,
+        extra_pip_args=state.installstate.extra_pip_args,
     )
     if retcode:
         ctx.abort()
