@@ -11,6 +11,7 @@ from pipenv.vendor.click import (
     echo,
     make_pass_decorator,
     option,
+    secho,
 )
 from pipenv.vendor.click import types as click_types
 from pipenv.vendor.click_didyoumean import DYMMixin
@@ -87,6 +88,7 @@ class InstallState:
         self.deploy = False
         self.packages = []
         self.editables = []
+        self.extra_pip_args = []
 
 
 class LockOptions:
@@ -286,10 +288,33 @@ def package_arg(f):
     )(f)
 
 
+def extra_pip_args(f):
+    def callback(ctx, param, value):
+        state = ctx.ensure_object(State)
+        if value:
+            for opt in value.split(" "):
+                state.installstate.extra_pip_args.append(opt)
+        return value
+
+    return option(
+        "--extra-pip-args",
+        nargs=1,
+        required=False,
+        callback=callback,
+        expose_value=True,
+        type=click_types.STRING,
+    )(f)
+
+
 def three_option(f):
     def callback(ctx, param, value):
         state = ctx.ensure_object(State)
         if value is not None:
+            secho(
+                "WARNING: --three is deprecated! pipenv uses python3 by default",
+                err=True,
+                fg="yellow",
+            )
             state.three = value
         return value
 
@@ -297,7 +322,7 @@ def three_option(f):
         "--three",
         is_flag=True,
         default=None,
-        help="Use Python 3 when creating virtualenv.",
+        help="Use Python 3 when creating virtualenv. Deprecated",
         callback=callback,
         expose_value=False,
     )(f)
@@ -570,6 +595,7 @@ def install_options(f):
     f = ignore_pipfile_option(f)
     f = editable_option(f)
     f = package_arg(f)
+    f = extra_pip_args(f)
     return f
 
 
